==> haskell-wai-3.2.4-146.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai
version:              3.2.4
visibility:           public
id:                   wai-3.2.4-DrO6v22Rmno6pXUhKStSuj
key:                  wai-3.2.4-DrO6v22Rmno6pXUhKStSuj
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  d81579a2bf8b2ea8238e651a0bbaa362
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-3.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-3.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai
hs-libraries:         HSwai-3.2.4-DrO6v22Rmno6pXUhKStSuj
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe text-2.0.2
    vault-0.3.1.5-1WesiFbrgeBJ6Pz5D8LxKa

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-3.2.4-147-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai
version:              3.2.4
visibility:           public
id:                   wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
key:                  wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  d6118a46fd833a4247d74d1dda545485
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-3.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-3.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai
hs-libraries:         HSwai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ text-2.0.2
    vault-0.3.1.5-A9Ty7yzuPZlIa80zuSIl14

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
